@@ -7,16 +7,13 @@ ZSHPower is a theme for ZSH with a manager.
 
 For more information, access: 'https://github.com/snakypy/zshpower'
 
-:copyright: Copyright 2020-2020 by Snakypy team, see AUTHORS.
+:copyright: Copyright 2020-2021 by Snakypy team, see AUTHORS.
 :license: MIT license, see LICENSE for details.
 """
 
-try:
-    from pathlib import Path
+from contextlib import suppress
+from pathlib import Path
 
+with suppress(KeyboardInterrupt):
     HOME = str(Path.home())
-
-    __version__ = "0.6.0"
-
-except (KeyboardInterrupt):
-    pass
+    __version__ = "0.7.0"
