@@ -1,8 +1,7 @@
 from datetime import datetime
 from zshpower import __version__
 
-
-content = f"""# Generate by: ZSHPower - D{datetime.today().isoformat()}
+content: str = f"""# Generate by: ZSHPower - D{datetime.today().isoformat()}
 # Version: {__version__}
 # ---------------------------------------------------------------------
 # For more information, see the documentation at:
@@ -28,20 +27,60 @@ position = [
     "dart",
     "dotnet",
     "docker",
+    "perl",
+    "scala",
+    "cmake",
+    "crystal",
+    "deno",
+    "erlang",
+    "helm",
+    "kotlin",
+    "nim",
+    "ocaml",
+    "vagrant",
+    "zig",
+    "gulp",
     "git"
     ]
 
-[username]
-enable = false
-symbol = "\\uf007"
-color = "cyan"
+[command]
+new_line.enable = true
+symbol = "\\u276f"
+color = "green"
+error.symbol = "\\u276f"
+error.color = "red"
 
-[hostname]
-enable = false
-symbol = "\\ue0a2"
+[cmake]
+symbol = "\\ufa35"
+color = "green"
+prefix.color = "white"
+prefix.text = "via"
+version.enable = false
+version.micro.enable = true
+
+[crystal]
+symbol = "\\uf7d7"
 color = "magenta"
 prefix.color = "white"
-prefix.text = "at"
+prefix.text = "via"
+version.enable = false
+version.micro.enable = true
+
+[dart]
+symbol = "\\ue798"
+color = "cyan"
+prefix.color = "white"
+prefix.text = "via"
+version.enable = false
+version.micro.enable = true
+
+[deno]
+symbol = "\\u1f995"
+color = "green"
+prefix.color = "white"
+prefix.text = "via"
+version.enable = false
+version.micro.enable = true
 
 [directory]
 truncation_length = 1
@@ -50,9 +89,41 @@ color = "cyan"
 prefix.color = "white"
 prefix.text = "in"
 
+[docker]
+symbol = "\\uf308"
+color = "cyan"
+prefix.color = "white"
+prefix.text = "on"
+version.enable = false
+version.micro.enable = true
+
+[dotnet]
+symbol = "\\ue77f"
+color = "cyan"
+prefix.color = "white"
+prefix.text = "via"
+version.enable = false
+version.micro.enable = true
+
+[elixir]
+symbol = "\\ue62d"
+color = "blue"
+prefix.color = "white"
+prefix.text = "via"
+version.enable = false
+version.micro.enable = true
+
+[erlang]
+symbol = "\\ue7b1"
+color = "red"
+prefix.color = "white"
+prefix.text = "via"
+version.enable = false
+version.micro.enable = true
+
 [git]
 enable = true
-symbol = "\\uf418"
+symbol = "\\ue725"
 branch.color = "cyan"
 color.symbol = "magenta"
 prefix.color = "white"
@@ -73,52 +144,6 @@ symbol.behind = "\\uf544"
 symbol.diverged = "\\ufb15"
 symbol.conflicts = "\\uf0e7"
 
-[command]
-new_line.enable = true
-symbol = "\\uf553"
-color = "green"
-error.symbol = "\\uf553"
-error.color = "red"
-
-[python]
-symbol = "\\uf81f"
-color = "yellow"
-prefix.color = "white"
-prefix.text = "via"
-version.enable = false
-version.micro.enable = true
-
-[package]
-enable = false
-symbol = "\\uf8d6"
-color = "red"
-prefix.color = "white"
-prefix.text = "is"
-
-[docker]
-symbol = "\\uf308"
-color = "cyan"
-prefix.color = "white"
-prefix.text = "on"
-version.enable = false
-version.micro.enable = true
-
-[nodejs]
-symbol = "\\uf898"
-color = "green"
-prefix.color = "white"
-prefix.text = "via"
-version.enable = false
-version.micro.enable = true
-
-[rust]
-symbol = "\\ue7a8"
-color = "red"
-prefix.color = "white"
-prefix.text = "via"
-version.enable = false
-version.micro.enable = true
-
 [golang]
 symbol = "\\ue627"
 color = "cyan"
@@ -127,33 +152,32 @@ prefix.text = "via"
 version.enable = false
 version.micro.enable = true
 
-[php]
-symbol = "\\ue608"
-color = "magenta"
-prefix.color = "white"
-prefix.text = "via"
-version.enable = false
-version.micro.enable = true
-
-[dart]
-symbol = "\\ue798"
-color = "cyan"
-prefix.color = "white"
-prefix.text = "via"
-version.enable = false
-version.micro.enable = true
-
-[java]
-symbol = "\\ue256"
+[gulp]
+symbol = "\\ue763"
 color = "red"
 prefix.color = "white"
 prefix.text = "via"
 version.enable = false
 version.micro.enable = true
 
-[elixir]
-symbol = "\\ue62d"
-color = "blue"
+[helm]
+symbol = "\\ufd31"
+color = "cyan"
+prefix.color = "white"
+prefix.text = "via"
+version.enable = false
+version.micro.enable = true
+
+[hostname]
+enable = false
+symbol = "\\ue0a2"
+color = "magenta"
+prefix.color = "white"
+prefix.text = "at"
+
+[java]
+symbol = "\\ue256"
+color = "red"
 prefix.color = "white"
 prefix.text = "via"
 version.enable = false
@@ -167,14 +191,85 @@ prefix.text = "via"
 version.enable = false
 version.micro.enable = true
 
-[dotnet]
-symbol = "\\ue77f"
-color = "cyan"
+[kotlin]
+symbol = "\\ue622"
+color = "blue"
 prefix.color = "white"
 prefix.text = "via"
-version.enable = true
+version.enable = false
 version.micro.enable = true
 
+[nim]
+symbol = "\\uf6a4"
+color = "yellow"
+prefix.color = "white"
+prefix.text = "via"
+version.enable = false
+version.micro.enable = true
+
+[nodejs]
+symbol = "\\uf898"
+color = "green"
+prefix.color = "white"
+prefix.text = "via"
+version.enable = false
+version.micro.enable = true
+
+[ocaml]
+symbol = "?"
+color = "yellow"
+prefix.color = "white"
+prefix.text = "via"
+version.enable = false
+version.micro.enable = true
+
+[package]
+enable = false
+symbol = "\\uf8d6"
+color = "red"
+prefix.color = "white"
+prefix.text = "is"
+
+[perl]
+symbol = "\\ue769"
+color = "blue"
+prefix.color = "white"
+prefix.text = "via"
+version.enable = false
+version.micro.enable = true
+
+[php]
+symbol = "\\ue608"
+color = "magenta"
+prefix.color = "white"
+prefix.text = "via"
+version.enable = false
+version.micro.enable = true
+
+[python]
+symbol = "\\uf81f"
+color = "yellow"
+prefix.color = "white"
+prefix.text = "via"
+version.enable = false
+version.micro.enable = true
+
+[python.virtualenv]
+enable = false
+symbol = "\\uf7c9"
+involved = "[]"
+color = "yellow"
+prefix.color = "white"
+prefix.text = "via"
+
+[python.virtualenv.name]
+normal.enable = true
+text = "venv"
+
+[python.virtualenv.poetry]
+py.enable = true
+hash.enable = true
+
 [ruby]
 symbol = "\\ue21e"
 color = "red"
@@ -183,21 +278,46 @@ prefix.text = "via"
 version.enable = false
 version.micro.enable = true
 
-[virtualenv]
-enable = false
-symbol = "\\uf7c9"
-involved = "()"
-color = "yellow"
+[rust]
+symbol = "\\ue7a8"
+color = "red"
 prefix.color = "white"
 prefix.text = "via"
+version.enable = false
+version.micro.enable = true
 
-[virtualenv.name]
-normal.enable = true
-text = "venv"
+[scala]
+symbol = "\\ue737"
+color = "red"
+prefix.color = "white"
+prefix.text = "via"
+version.enable = false
+version.micro.enable = true
 
 [timer]
 enable = false
 symbol = "\\uf43a"
 color = "blue"
 seconds.enable = false
+
+[username]
+enable = false
+symbol = "\\uf007"
+color = "cyan"
+
+[vagrant]
+symbol = "\\ue62b"
+color = "yellow"
+prefix.color = "white"
+prefix.text = "via"
+version.enable = false
+version.micro.enable = true
+
+[zig]
+symbol = "\\ue00a"
+color = "yellow"
+prefix.color = "white"
+prefix.text = "via"
+version.enable = false
+version.micro.enable = true
 """
