@@ -1,7 +1,10 @@
+from contextlib import suppress
+from datetime import datetime
 from functools import wraps
+from typing import Any
 
 
-def assign_cli(arguments, command):
+def assign_cli(arguments: dict, command: str) -> Any:
     def decorator(func):
         @wraps(func)
         def wrapper(*args, **kwargs):
@@ -13,7 +16,7 @@ def assign_cli(arguments, command):
     return decorator
 
 
-def runtime(func):
+def runtime(func: Any):
     """Decorator to test runtime others functions.
 
     Returns:
@@ -22,8 +25,6 @@ def runtime(func):
 
     @wraps(func)
     def wrapper(*args, **kwargs):
-        from datetime import datetime
-
         start_time = datetime.now()
         context = func(*args, **kwargs)
         print(f"Time taken: {datetime.now() - start_time}")
@@ -33,11 +34,24 @@ def runtime(func):
 
 
 def silent_errors(func):
-    from contextlib import suppress
-
     @wraps(func)
     def wrapper(*args, **kwargs):
         with suppress(NameError, TypeError, KeyboardInterrupt):
             return func(*args, **kwargs)
 
     return wrapper
+
+
+# def invisible_cursor(func):
+#     import curses
+#     from time import sleep
+#
+#     @wraps(func)
+#     def wrapper(*args, **kwargs):
+#         curses.initscr()
+#         curses.curs_set(0)
+#         f = func(*args, **kwargs)
+#         curses.curs_set(1)
+#         curses.endwin()
+#         return f
+#     return wrapper
